cohens_plot: Calculate and plots Cohen's d given given some descriptive...

Description Usage Arguments Value Examples

View source: R/cohens_plot.R

Description

Calculate and plots Cohen's d given given some descriptive statistic

Usage

1
cohens_plot(mean.one, mean.two, sd.one, sd.two, overlap = TRUE)

Arguments

mean.one

consumes the mean of first group

mean.two

consumes the mean of second group

sd.one

consumes the standard deviation of first group

sd.two

consumes the standard deviation of second group.

overlap

default is set to true. Type false if you do not want an overlap in the plots.

Value

a ggplot showing the effect for the given mean and standard deviation

Examples

1
2
3
cohens_plot(0, 1, 0.5, 0.8, overlap = FALSE)
cohens_plot(0, 1, 0.5, 0.8)
cohens_plot(0, 1, 0.5, 0.8, overlap = TRUE)

andr3wli/powerPsych documentation built on Dec. 31, 2020, 7:46 p.m.