Description Usage Arguments Value Examples
Calculate and plots Cohen's d given given some descriptive statistic
1 | cohens_plot(mean.one, mean.two, sd.one, sd.two, overlap = TRUE)
|
mean.one |
consumes the mean of first group |
mean.two |
consumes the mean of second group |
sd.one |
consumes the standard deviation of first group |
sd.two |
consumes the standard deviation of second group. |
overlap |
default is set to true. Type false if you do not want an overlap in the plots. |
a ggplot showing the effect for the given mean and standard deviation
1 2 3 | cohens_plot(0, 1, 0.5, 0.8, overlap = FALSE)
cohens_plot(0, 1, 0.5, 0.8)
cohens_plot(0, 1, 0.5, 0.8, overlap = TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.